@@ -44,6 +44,7 @@ MANAGER_ATTRS = {
     'extra',
     'get',
     'get_or_create',
+    'update_or_create',
     'get_queryset',
     'create',
     'bulk_create',
@@ -310,7 +311,7 @@ def ignore_import_warnings_for_related_fields(orig_method, self, node):
     iterat = consumer.to_consume.items if PY3 else consumer.to_consume.iteritems
     for name, stmts in iterat():
         if isinstance(stmts[0], ImportFrom):
-            if any([n[0] in ('ForeignKey', 'OneToOneField') for n in stmts[0].names]):
+            if any(n[0] in ('ForeignKey', 'OneToOneField') for n in stmts[0].names):
                 continue
         new_things[name] = stmts
 
@@ -629,8 +630,8 @@ def generic_is_view_attribute(parents, attrs):
 
 
 def is_model_view_subclass_method_shouldnt_be_function(node):
-    """Checks that node is get or post method of the View class."""
-    if node.name not in ('get', 'post'):
+    """Checks that node is a default http method (i.e get, post, put, and more) of the View class."""
+    if node.name not in View.http_method_names:
         return False
 
     parent = node.parent
@@ -651,7 +652,7 @@ def ignore_unused_argument_warnings_for_request(orig_method, self, stmt, name):
     The signature of Django view functions require the request argument but it is okay if the request is not used.
     This function should be used as a wrapper for the `VariablesChecker._is_name_ignored` method.
     """
-    if name == 'request':
+    if name in ('request', 'args', 'kwargs'):
         return True
 
     return orig_method(self, stmt, name)
