@@ -6,7 +6,7 @@ having explicitly defined __unicode__
 #  pylint: disable=missing-docstring
 
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
+from six import python_2_unicode_compatible
 
 
 @python_2_unicode_compatible
