@@ -3,4 +3,5 @@ from django.db import models
 
 
 class Author(models.Model):
-    pass
+    class Meta:
+        app_label = 'test_app'
